@@ -8,15 +8,15 @@ use Import::Export;
 
 use base qw/Import::Export/;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our %EX = (
 	entropy => [qw/all/]
 );
 
 sub entropy {
-	my ($entropy, $p, %t) = 0;
-	return ((map { $p = $_/length($_[0]); $entropy -= $p * log $p } (map { $t{$_}++ } split '', $_[0]) && values %t) and $entropy / log 2);
+	my ($entropy, $len, $p, %t) = (0, length($_[0]));
+	return ((map { $p = $_/$len; $entropy -= $p * log $p } (map { $t{$_}++ } split '', $_[0]) && values %t) and $entropy / log 2);
 }
 
 =head1 NAME
@@ -25,7 +25,7 @@ Shannon::Entropy - Calculate the Shannon entropy H of a given input string.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
